.. _tutorials:

Advanced Usage
==============

These tutorials give some examples in the use of the 
underlying ``radvel`` API. 
They are also available as interactive iPython notebooks
in the `docs/tutorials` subdirectory of the radvel package.

.. toctree::
   :maxdepth: 2

   tutorials/K2-24_Fitting+MCMC.ipynb
   tutorials/GaussianProcess-tutorial.ipynb
   tutorials/CustomModel-tutorial.ipynb

